@@ -4,6 +4,5 @@ CREATE TABLE ts2_clients (
   b_client_privilege_serveradmin integer,
   s_client_name varchar(40),
   s_client_password varchar(80),
-  dt_client_created varchar(20),
-  dt_client_lastonline varchar(20)
+  dt_client_created varchar(20)
 );
